@@ -1,13 +1,12 @@
 package Dev::Util;
 
-use lib 'lib';
 use 5.018;
 use strict;
 use warnings;
 use version;
-use Carp;
+use Carp qw(carp);
 
-our $VERSION = version->declare("v2.18.31");
+our $VERSION = version->declare("v2.18.35");
 
 use Exporter   qw( );
 use List::Util qw( uniq );
@@ -57,7 +56,7 @@ Dev::Util - Base modules for Perl Development
 
 =head1 VERSION
 
-Version v2.18.31
+Version v2.18.35
 
 =head1 SYNOPSIS
 
@@ -98,7 +97,7 @@ L<Dev::Util::Sem>,
 
 =head1 AUTHOR
 
-Matt Martini,  C<< <matt at imaginarywave.com> >>
+Matt Martini, C<< <matt.martini at imaginarywave.com> >>
 
 =head1 BUGS
 
